package App::wdq;
use v5.14;

our $VERSION = '0.4.4';

1;
__END__

=head1 NAME

App::wdq - command line access to Wikidata Query Service

=head1 DESCRIPTION

See command line script L<wdq> for documentation.

=head1 COPYRIGHT AND LICENSE

Copyright Jakob Voss, 2015-

GPL 2.0

=cut
